netapp_ontap.models.datacollection_rag API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.datacollection_rag`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DatacollectionRagSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DatacollectionRag object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `url: str GET`

    The URL for the Retrieval-Augmented Generation (RAG) endpoint.

    Example: https://1.2.3.4/api/data-engine/workspaces/02c9e252-41be-11e9-81d5-00a0986138f7/data-collections/123e4567-e89b-12d3-a456-426614174000/search